@@ -1,6 +1,8 @@
 package List::Objects::Types;
-$List::Objects::Types::VERSION = '1.003001';
-use strict; use warnings FATAL => 'all';
+$List::Objects::Types::VERSION = '1.003002';
+use strict; use warnings;
+
+use List::Util ();
 
 use Type::Library   -base;
 use Type::Utils     -all;
@@ -104,7 +106,10 @@ declare InflatedHash =>
   as InstanceOf['List::Objects::WithUtils::Hash::Inflated'],
   constraint_generator => sub {
     my @params = @_;
-    sub { Scalar::Util::blessed $_ and not grep(!$_[0]->can($_), @params) }
+    sub { 
+      Scalar::Util::blessed $_
+        and not List::Util::first { !$_[0]->can($_) } @params
+    }
   };
 
 coerce InflatedHash =>
@@ -196,8 +201,7 @@ List::Objects::Types - Type::Tiny-based types for List::Objects::WithUtils
 
   use List::Objects::Types -all;
   use List::Objects::WithUtils;
-  use Moo;
-  use MooX::late;
+  use Moo 2;  # version 2+ for better Type::Tiny support
 
   has my_array => (
     is  => 'ro',
@@ -318,11 +322,15 @@ An object that isa L<List::Objects::WithUtils::Hash::Inflated>.
 
 Can be coerced from a plain HASH or an L</HashObj>.
 
+(Available from v1.2.1)
+
 =head3 InflatedHash[`a]
 
 InflatedHash can be parameterized with a list of methods expected to be
 available.
 
+(Available from v1.3.1)
+
 =head2 SEE ALSO
 
 L<MoopsX::ListObjects> for integration with L<Moops> class-building sugar.
